import { BehaviorSubject } from 'rxjs';
import type { Metadata, SchemaResponse } from '../metadata';
import { MetadataCache } from '../metadata';
import { ConnectConfig } from './connect.types';
import { CommitParams, Message, MessageBuilder, RequestParams } from './message';
import type { SocketObservable } from './socket';
import { Socket } from './socket';
export type ConnectionStatus = 'connected' | 'disconnected' | 'busy';
export declare const defaultConnectConfig: ConnectConfig;
export interface Connect {
    isConnected: boolean;
    status: ConnectionStatus;
    _status: BehaviorSubject<ConnectionStatus>;
    _hostUrl: BehaviorSubject<String>;
    send<T>(message: Message<T | any>, needsHandling?: boolean): Promise<Message | any>;
    httpMode(): boolean;
    connect(host: string): Promise<boolean>;
    disconnect(): void;
    setValidSession(valid: boolean): void;
    snapshot(resourceName: string, params?: any): Promise<Message>;
    stream(resourceName: string, onMessage: Function, onError: Function, params?: any): SocketObservable<Message>;
    getMoreRows(sourceRef: string): Promise<Message>;
    dataLogoff(sourceRef: string): Promise<Message>;
    getMetadata(resourceName: string): Promise<Metadata>;
    getJSONSchema(resourceName: string): Promise<SchemaResponse>;
    request(resourceName: string, params?: RequestParams): Promise<Message>;
    commitEvent(eventName: string, params?: CommitParams): Promise<Message>;
}
export declare class DefaultConnect implements Connect {
    socket: Socket;
    private messageBuilder;
    private metaCache;
    private config;
    constructor(socket: Socket, messageBuilder: MessageBuilder, metaCache: MetadataCache, config?: ConnectConfig);
    get isConnected(): boolean;
    get status(): ConnectionStatus;
    set status(status: ConnectionStatus);
    _status: BehaviorSubject<ConnectionStatus>;
    _hostUrl: BehaviorSubject<String>;
    httpMode(): boolean;
    setValidSession(valid: boolean): void;
    send<T>(message: Message<any>, needsHandling?: boolean): Promise<any>;
    connect(host: string): Promise<boolean>;
    disconnect(): void;
    snapshot(resourceName: string, params?: any): Promise<Message>;
    stream(resourceName: string, onMessage: Function, onError: Function, params?: any): SocketObservable<Message>;
    getMoreRows(sourceRef: string): Promise<Message>;
    dataLogoff(streamSourceRef: string): Promise<Message>;
    getMetadata(resourceName: string, useCache?: boolean): Promise<Metadata>;
    getJSONSchema(resourceName: string): Promise<SchemaResponse>;
    request(resourceName: string, params?: RequestParams): Promise<Message>;
    commitEvent(eventName: string, params?: CommitParams): Promise<Message>;
}
export declare const WSConnect: import("@microsoft/fast-foundation").InterfaceSymbol<Connect>;
export declare const Connect: import("@microsoft/fast-foundation").InterfaceSymbol<Connect>;
//# sourceMappingURL=connect.d.ts.map