import { Auth } from '../auth';
import { Connect, Message, SocketObservable } from '../connect';
import type { FieldMetadata, FilteredDataServerResult, IndexDetail, MetadataDetail, RequestServerResult } from '../metadata/metadata.types';
import type { DatasourceOptions, Dataview } from './datasource.types';
import { DatasourceConfig, ResourceType } from './datasource.types';
export declare const defaultDatasourceConfig: DatasourceConfig;
export interface Datasource {
    initialized: boolean;
    fieldMetadata: FieldMetadata[];
    readOnly: boolean;
    resourceType: ResourceType;
    stream: SocketObservable<FilteredDataServerResult | RequestServerResult>;
    init(options: DatasourceOptions, fetchMeta: boolean): Promise<boolean>;
    getMetadata?(resourceName: string): Promise<Array<FieldMetadata>>;
    snapshot(params?: any): any;
    snapshotFiltered(rowId?: string): any;
    updateData?(data: Array<any>): Promise<void>;
    dataHandler?(data: Array<any>): Array<any>;
    addView?(view: Dataview): void;
    dropView?(view: Dataview): void;
    setFilter?(name: string, value: any, type?: string): Promise<void>;
    clearFilter?(name: string): Promise<void>;
    createItem?(data: any): Promise<string>;
    deleteItem?(itemId: string): Promise<void>;
    updateItem?(itemId: string, data: any): Promise<void>;
}
export declare class DefaultDatasource implements Datasource {
    protected connect: Connect;
    protected auth: Auth;
    protected config: DatasourceConfig;
    initialized: boolean;
    readOnly: boolean;
    protected options: DatasourceOptions;
    resourceType: ResourceType;
    protected _stream: SocketObservable<FilteredDataServerResult | RequestServerResult>;
    protected originalFieldDef: MetadataDetail[];
    protected requestFields: MetadataDetail[];
    fieldMetadata: FieldMetadata[];
    protected availableIndexes: IndexDetail[];
    constructor(connect: Connect, auth: Auth, config?: DatasourceConfig);
    init(options: DatasourceOptions, fetchMeta?: boolean): Promise<boolean>;
    get stream(): SocketObservable<FilteredDataServerResult | RequestServerResult>;
    get params(): any;
    snapshot(): Promise<Message>;
    snapshotFiltered(rowId?: string): Promise<any[]>;
    private createStream;
    private createDataserverStream;
    private createReqRepStream;
    private validResourceName;
}
export declare const Datasource: import("@microsoft/fast-foundation").InterfaceSymbol<Datasource>;
//# sourceMappingURL=datasource.d.ts.map